@@ -19,7 +19,7 @@ class AMQPBus(object):
     def __init__(self, host, username, password, exchange):
         self.conn = amqp.Connection(host, userid=username, password=password)
         self.ch = self.conn.channel()
-        self.ch.exchange_declare(exchange, type='topic', auto_delete=False)
+        self.ch.exchange_declare(exchange, type='topic', auto_delete=False, durable=True)
         self.exchange = exchange
 
     def sendto(self, body, key):
